@@ -35,6 +35,7 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to_not contain_package('cryptsetup').with( :ensure => 'present' )}
 
@@ -146,6 +147,32 @@ describe 'nova::compute' do
       end
     end
 
+    context 'with reserved_huge_pages string' do
+      let :params do
+        {
+            :reserved_huge_pages => "foo"
+        }
+      end
+      it 'configures nova reserved_huge_pages entries' do
+        is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with(
+          'value' => 'foo'
+        )
+      end
+    end
+
+    context 'with reserved_huge_pages array' do
+      let :params do
+        {
+            :reserved_huge_pages => ["foo", "bar"]
+        }
+      end
+      it 'configures nova reserved_huge_pages entries' do
+        is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with(
+          'value' => ['foo','bar']
+        )
+      end
+    end
+
     context 'with pci params array' do
       let :params do
         {
